Module kv

Module kv 

Key-value pairs in a log record or a diagnostic context.

Structs

DebugValue
A value captured through its fmt::Debug representation.
DisplayValue
A value captured through its fmt::Display representation.
Key
A key in a key-value pair.
KeyOwned
An owned key in a key-value pair.
KeyValues
A collection of key-value pairs.
KeyValuesIter
An iterator over key-value pairs.
KeyView
A borrowed view of a key in a key-value pair.
ListValue
A borrowed view over a list value.
ListValueIter
An iterator over list values.
MapValue
A borrowed view over a map value.
MapValueIter
An iterator over map key-value pairs.
Value
A borrowed value in a key-value pair.
ValueOwned
An owned value in a key-value pair.

Enums

ValueView
A borrowed view of a value.

Traits

Visitor
A visitor to walk through key-value pairs.