ValueView

Enum ValueView 

#[non_exhaustive]
pub enum ValueView<'a> {
Show 15 variants None, BorrowedStr(&'a str), StaticStr(&'static str), Bytes(&'a [u8]), Bool(bool), I64(i64), U64(u64), F64(f64), I128(i128), U128(u128), Char(char), List(ListValue<'a>), Map(MapValue<'a>), Debug(DebugValue<'a>), Display(DisplayValue<'a>),
}
A borrowed view of a value.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


None

The absence of a value.



BorrowedStr(&'a str)

A borrowed string value.



StaticStr(&'static str)

A static string value.



Bytes(&'a [u8])

A byte array value.



Bool(bool)

A boolean value.



I64(i64)

A signed 64-bit integer value.



U64(u64)

An unsigned 64-bit integer value.



F64(f64)

A 64-bit floating point value.



I128(i128)

A signed 128-bit integer value.



U128(u128)

An unsigned 128-bit integer value.



Char(char)

A Unicode scalar value.



List(ListValue<'a>)

A list value.



Map(MapValue<'a>)

A map value.



Debug(DebugValue<'a>)

A lazily debug-formatted value.



Display(DisplayValue<'a>)

A lazily display-formatted value.

Implementations

Source

impl ValueView<'_>

pub fn to_owned(&self) -> ValueOwned

Convert this view into an owned value.

Source

impl<'a> ValueView<'a>

pub fn to_bool(&self) -> Option<bool>

Try to convert this view into a boolean.

pub fn to_i64(&self) -> Option<i64>

Try to convert this view into a signed 64-bit integer.

pub fn to_u64(&self) -> Option<u64>

Try to convert this view into an unsigned 64-bit integer.

pub fn to_f64(&self) -> Option<f64>

Try to convert this view into a 64-bit floating point number.

pub fn to_i128(&self) -> Option<i128>

Try to convert this view into a signed 128-bit integer.

pub fn to_u128(&self) -> Option<u128>

Try to convert this view into an unsigned 128-bit integer.

pub fn to_char(&self) -> Option<char>

Try to convert this view into a Unicode scalar value.

pub fn to_str(&self) -> Option<&'a str>

Try to convert this view into a string slice.

pub fn to_static_str(&self) -> Option<&'static str>

Try to convert this view into a static string slice.

pub fn to_display(&self) -> Option<DisplayValue<'a>>

Try to convert this view into a display-formatted value.

pub fn to_list(&self) -> Option<ListValue<'a>>

Try to convert this view into a list value.

pub fn to_map(&self) -> Option<MapValue<'a>>

Try to convert this view into a map value.

pub fn to_debug(&self) -> Option<DebugValue<'a>>

Try to convert this view into a debug-formatted value.