Value

Struct Value 

pub struct Value<'a>(/* private fields */);
A borrowed value in a key-value pair.

Implementations

Source

impl Value<'_>

pub fn view(&self) -> ValueView<'_>

Create a borrowed view of this value.

Source

impl<'a> Value<'a>

pub fn none() -> Value<'a>

Create a value representing the absence of data.

pub fn str(s: &'a str) -> Self

Create a value from a borrowed string.

pub fn static_str(s: &'static str) -> Self

Create a value from a static string.

pub fn bytes(b: &'a [u8]) -> Self

Create a value from a byte array.

pub fn bool(b: bool) -> Self

Create a value from a boolean.

pub fn i64(i: i64) -> Self

Create a value from a signed 64-bit integer.

pub fn u64(u: u64) -> Self

Create a value from an unsigned 64-bit integer.

pub fn f64(f: f64) -> Self

Create a value from a 64-bit floating point number.

pub fn i128(i: i128) -> Self

Create a value from a signed 128-bit integer.

pub fn u128(u: u128) -> Self

Create a value from an unsigned 128-bit integer.

pub fn char(c: char) -> Self

Create a value from a Unicode scalar value.

pub fn list(l: &'a [Value<'a>]) -> Self

Create a value from a borrowed list of values.

pub fn map(m: &'a [(Key<'a>, Value<'a>)]) -> Self

Create a value from a borrowed map of key-value pairs.

pub fn debug(d: &'a dyn Debug) -> Self

Create a value that is formatted lazily with fmt::Debug.

pub fn display(d: &'a dyn Display) -> Self

Create a value that is formatted lazily with fmt::Display.