Key-value pairs in a log record or a diagnostic context.
Structs
- Debug
Value - A value captured through its
fmt::Debugrepresentation. - Display
Value - A value captured through its
fmt::Displayrepresentation. - Key
- A key in a key-value pair.
- KeyOwned
- An owned key in a key-value pair.
- KeyValues
- A collection of key-value pairs.
- KeyValues
Iter - An iterator over key-value pairs.
- KeyView
- A borrowed view of a key in a key-value pair.
- List
Value - A borrowed view over a list value.
- List
Value Iter - An iterator over list values.
- MapValue
- A borrowed view over a map value.
- MapValue
Iter - An iterator over map key-value pairs.
- Value
- A borrowed value in a key-value pair.
- Value
Owned - An owned value in a key-value pair.
Enums
- Value
View - A borrowed view of a value.
Traits
- Visitor
- A visitor to walk through key-value pairs.