pub struct Value<'a>(/* private fields */);Expand description
A borrowed value in a key-value pair.
Implementations
Sourceimpl<'a> Value<'a>
impl<'a> Value<'a>
Sourcepub fn static_str(s: &'static str) -> Self
pub fn static_str(s: &'static str) -> Self
Create a value from a static string.
Sourcepub fn map(m: &'a [(Key<'a>, Value<'a>)]) -> Self
pub fn map(m: &'a [(Key<'a>, Value<'a>)]) -> Self
Create a value from a borrowed map of key-value pairs.
Sourcepub fn debug(d: &'a dyn Debug) -> Self
pub fn debug(d: &'a dyn Debug) -> Self
Create a value that is formatted lazily with fmt::Debug.
Sourcepub fn display(d: &'a dyn Display) -> Self
pub fn display(d: &'a dyn Display) -> Self
Create a value that is formatted lazily with fmt::Display.